package com.idiot.operationbackend.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.idiot.operationbackend.entity.AccountFansStat;
import com.idiot.operationbackend.mappers.AccountFansStatMapper;
import com.idiot.operationbackend.service.facade.AccountFansStatService;
import com.idiot.operationbackend.service.facade.WeChatService;
import com.idiot.operationbackend.support.Constants;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import javax.servlet.http.Cookie;
import java.time.LocalDate;
import java.util.List;

/**
 * 公众号数据统计
 * @author wang xiao
 * @date Created in 14:54 2020/9/15
 */
@Service
public class AccountFansStatServiceImpl extends ServiceImpl<AccountFansStatMapper, AccountFansStat>
        implements AccountFansStatService {



    @Autowired
    private WeChatService weChatService;


    @Override
    public List<AccountFansStat> queryByDateAndAccIds(List<String> accountIds, String statDate) {
        return list(Wrappers.<AccountFansStat>lambdaQuery().eq(AccountFansStat::getStatDate,statDate)
                .in(AccountFansStat::getAccountId,accountIds));
    }


    @Override
    public AccountFansStat queryByDateAndAccountId(String accountId, String statDate) {
        return getOne(Wrappers.<AccountFansStat>lambdaQuery()
                .eq(AccountFansStat::getAccountId,accountId)
                .eq(AccountFansStat::getStatDate,statDate));
    }


    @Override
    @Async("asyncExecutor")
    public void statAccountFansData(String accountId) {
        String yesterday = Constants.DATE_FORMATTER.format(LocalDate.now().plusDays(-1));
        String jsonStr = weChatService.getFansSunmmary(accountId,yesterday,yesterday);
        JSONObject jsonObject = JSONObject.parseObject(jsonStr);
        JSONArray jsonArray = jsonObject.getJSONArray("list");
        int size  = jsonArray.size();
        int newNum = 0;
        int cancelNum = 0;
        JSONObject tempObject = null;
        // 昨日增减
        for (int i = 0; i < size; i++) {
            tempObject = jsonArray.getJSONObject(i);
            newNum += tempObject.getInteger("new_user");
            cancelNum += tempObject.getInteger("cancel_user");
        }
        int totalNum = 0;
        // 昨日汇总
        String jsonStrTotal = weChatService.getFansCumulate(accountId,yesterday,yesterday);
        JSONObject jsonObjectTotal = JSONObject.parseObject(jsonStrTotal);
        JSONArray jsonArrayTotal = jsonObjectTotal.getJSONArray("list");
        int sizeTotal  = jsonArrayTotal.size();
        for (int i = 0; i < sizeTotal; i++) {
            tempObject = jsonArray.getJSONObject(i);
            totalNum += tempObject.getInteger("cumulate_user");
        }


        
    }

}
